@@ -30,21 +30,22 @@
 #include "csapi/whoami.h"
 
 #include "events/directchatevent.h"
+#include "events/encryptionevent.h"
 #include "jobs/downloadfilejob.h"
 #include "jobs/mediathumbnailjob.h"
 #include "jobs/syncjob.h"
 
 #ifdef Quotient_E2EE_ENABLED
-#    include "connectionencryptiondata_p.h"
-#    include "database.h"
+    #include "connectionencryptiondata_p.h"
+    #include "database.h"
 
-#    include "e2ee/qolminboundsession.h"
+    #include "e2ee/qolminboundsession.h"
 #endif // Quotient_E2EE_ENABLED
 
 #if QT_VERSION_MAJOR >= 6
-#    include <qt6keychain/keychain.h>
+    #include <qt6keychain/keychain.h>
 #else
-#    include <qt5keychain/keychain.h>
+    #include <qt5keychain/keychain.h>
 #endif
 
 #include <QtCore/QCoreApplication>
@@ -342,7 +343,6 @@ void Connection::Private::completeSetup(const QString& mxId, bool mock)
                 _impl::ConnectionEncryptionData::setup(q, mock)) {
             encryptionData = std::move(*maybeEncryptionData);
         } else {
-            Q_ASSERT(false);
             useEncryption = false;
             emit q->encryptionChanged(false);
         }
@@ -575,6 +575,9 @@ void Connection::Private::consumeAccountData(Events&& accountDataEvents)
                 remove_if(directChatUsers, [&remoteRemovals](auto it) {
                     return remoteRemovals.contains(it.value(), it.key());
                 });
+                remove_if(directChatMemberIds, [&remoteRemovals, this](auto it) {
+                    return remoteRemovals.contains(q->user(it.value()), it.key());
+                });
                 // Remove from dcLocalRemovals what the server already has.
                 remove_if(dcLocalRemovals, [&remoteRemovals](auto it) {
                     return remoteRemovals.contains(it.key(), it.value());
@@ -596,6 +599,7 @@ void Connection::Private::consumeAccountData(Events&& accountDataEvents)
                             remoteAdditions.insert(u, it.value());
                             directChats.insert(u, it.value());
                             directChatUsers.insert(it.value(), u);
+                            directChatMemberIds.insert(it.value(), it.key());
                             qCDebug(MAIN) << "Marked room" << it.value()
                                           << "as a direct chat with" << u->id();
                         }
@@ -904,6 +908,7 @@ void Connection::doInDirectChat(User* u,
             d->directChats.remove(it.key(), it.value());
             d->directChatUsers.remove(it.value(),
                                       const_cast<User*>(it.key())); // FIXME
+            d->directChatMemberIds.remove(it.value(), it.key()->id());
         }
         emit directChatsListChanged({}, removals);
     }
@@ -920,8 +925,16 @@ CreateRoomJob* Connection::createDirectChat(const QString& userId,
                                             const QString& topic,
                                             const QString& name)
 {
+    QVector<CreateRoomJob::StateEvent> initialStateEvents;
+
+    if (d->encryptDirectChats) {
+        const auto encryptionContent = EncryptionEventContent(EncryptionType::MegolmV1AesSha2);
+        initialStateEvents.append({ EncryptionEvent::TypeId, encryptionContent.toJson() });
+    }
+
     return createRoom(UnpublishRoom, {}, name, topic, { userId },
-                      QStringLiteral("trusted_private_chat"), {}, true);
+                      QStringLiteral("trusted_private_chat"), {}, true,
+                      initialStateEvents);
 }
 
 ForgetRoomJob* Connection::forgetRoom(const QString& id)
@@ -1122,6 +1135,17 @@ User* Connection::user() { return user(userId()); }
 
 QString Connection::userId() const { return d->data->userId(); }
 
+Avatar& Connection::userAvatar(const QString& avatarMediaId)
+{
+    return userAvatar(QUrl(avatarMediaId));
+}
+
+Avatar& Connection::userAvatar(const QUrl& avatarUrl)
+{
+    const auto mediaId = avatarUrl.authority() + avatarUrl.path();
+    return d->userAvatarMap.try_emplace(mediaId, avatarUrl).first->second;
+}
+
 QString Connection::deviceId() const { return d->data->deviceId(); }
 
 QByteArray Connection::accessToken() const
@@ -1158,7 +1182,7 @@ QVector<Room*> Connection::allRooms() const
 QVector<Room*> Connection::rooms(JoinStates joinStates) const
 {
     QVector<Room*> result;
-    for (auto* r: qAsConst(d->roomMap))
+    for (auto* r: std::as_const(d->roomMap))
         if (joinStates.testFlag(r->joinState()))
             result.push_back(r);
     return result;
@@ -1205,7 +1229,7 @@ void Connection::setAccountData(const QString& type, const QJsonObject& content)
 QHash<QString, QVector<Room*>> Connection::tagsToRooms() const
 {
     QHash<QString, QVector<Room*>> result;
-    for (auto* r : qAsConst(d->roomMap)) {
+    for (auto* r : std::as_const(d->roomMap)) {
         const auto& tagNames = r->tagNames();
         for (const auto& tagName : tagNames)
             result[tagName].push_back(r);
@@ -1220,7 +1244,7 @@ QHash<QString, QVector<Room*>> Connection::tagsToRooms() const
 QStringList Connection::tagNames() const
 {
     QStringList tags({ FavouriteTag });
-    for (auto* r : qAsConst(d->roomMap)) {
+    for (auto* r : std::as_const(d->roomMap)) {
         const auto& tagNames = r->tagNames();
         for (const auto& tag : tagNames)
             if (tag != LowPriorityTag && !tags.contains(tag))
@@ -1256,6 +1280,20 @@ void Connection::Private::removeRoom(const QString& roomId)
         }
 }
 
+void Connection::addToDirectChats(const Room* room, const QString& userId)
+{
+    Q_ASSERT(room != nullptr && !userId.isEmpty());
+    const auto u = user(userId);
+    if (d->directChats.contains(u, room->id()))
+        return;
+    Q_ASSERT(!d->directChatUsers.contains(room->id(), u));
+    d->directChats.insert(u, room->id());
+    d->directChatMemberIds.insert(room->id(), userId);
+    d->directChatUsers.insert(room->id(), u);
+    d->dcLocalAdditions.insert(u, room->id());
+    emit directChatsListChanged({ { u, room->id() } }, {});
+}
+
 void Connection::addToDirectChats(const Room* room, User* user)
 {
     Q_ASSERT(room != nullptr && user != nullptr);
@@ -1263,11 +1301,36 @@ void Connection::addToDirectChats(const Room* room, User* user)
         return;
     Q_ASSERT(!d->directChatUsers.contains(room->id(), user));
     d->directChats.insert(user, room->id());
+    d->directChatMemberIds.insert(room->id(), user->id());
     d->directChatUsers.insert(room->id(), user);
     d->dcLocalAdditions.insert(user, room->id());
     emit directChatsListChanged({ { user, room->id() } }, {});
 }
 
+void Connection::removeFromDirectChats(const QString& roomId, const QString& userId)
+{
+    Q_ASSERT(!roomId.isEmpty());
+    const auto u = user(userId);
+    if ((!userId.isEmpty() && !d->directChats.contains(u, roomId))
+        || d->directChats.key(roomId) == nullptr)
+        return;
+
+    DirectChatsMap removals;
+    if (u != nullptr) {
+        d->directChats.remove(u, roomId);
+        d->directChatUsers.remove(roomId, u);
+        d->directChatMemberIds.remove(roomId, u->id());
+        removals.insert(u, roomId);
+        d->dcLocalRemovals.insert(u, roomId);
+    } else {
+        removals = remove_if(d->directChats,
+                            [&roomId](auto it) { return it.value() == roomId; });
+        d->directChatUsers.remove(roomId);
+        d->dcLocalRemovals += removals;
+    }
+    emit directChatsListChanged({}, removals);
+}
+
 void Connection::removeFromDirectChats(const QString& roomId, User* user)
 {
     Q_ASSERT(!roomId.isEmpty());
@@ -1279,6 +1342,7 @@ void Connection::removeFromDirectChats(const QString& roomId, User* user)
     if (user != nullptr) {
         d->directChats.remove(user, roomId);
         d->directChatUsers.remove(roomId, user);
+        d->directChatMemberIds.remove(roomId, user->id());
         removals.insert(user, roomId);
         d->dcLocalRemovals.insert(user, roomId);
     } else {
@@ -1292,7 +1356,13 @@ void Connection::removeFromDirectChats(const QString& roomId, User* user)
 
 bool Connection::isDirectChat(const QString& roomId) const
 {
-    return d->directChatUsers.contains(roomId);
+    return d->directChatMemberIds.contains(roomId);
+}
+
+QList<QString> Connection::directChatMemberIds(const Room* room) const
+{
+    Q_ASSERT(room != nullptr);
+    return d->directChatMemberIds.values(room->id());
 }
 
 QList<User*> Connection::directChatUsers(const Room* room) const
@@ -1330,6 +1400,16 @@ void Connection::addToIgnoredUsers(const User* user)
     }
 }
 
+void Connection::addToIgnoredUsers(const QString& userId)
+{
+    auto ignoreList = ignoredUsers();
+    if (!ignoreList.contains(userId)) {
+        ignoreList.insert(userId);
+        d->packAndSendAccountData<IgnoredUsersEvent>(ignoreList);
+        emit ignoredUsersListChanged({ { userId } }, {});
+    }
+}
+
 void Connection::removeFromIgnoredUsers(const User* user)
 {
     Q_ASSERT(user != nullptr);
@@ -1341,6 +1421,15 @@ void Connection::removeFromIgnoredUsers(const User* user)
     }
 }
 
+void Connection::removeFromIgnoredUsers(const QString& userId)
+{
+    auto ignoreList = ignoredUsers();
+    if (ignoreList.remove(userId) != 0) {
+        d->packAndSendAccountData<IgnoredUsersEvent>(ignoreList);
+        emit ignoredUsersListChanged({}, { { userId } });
+    }
+}
+
 QMap<QString, User*> Connection::users() const { return d->userMap; }
 
 const ConnectionData* Connection::connectionData() const
@@ -1423,6 +1512,11 @@ void Connection::setEncryptionDefault(bool useByDefault)
 {
     Private::encryptionDefault = useByDefault;
 }
+
+void Connection::setDirectChatEncryptionDefault(bool useByDefault)
+{
+    Private::directChatEncryptionDefault = useByDefault;
+}
 #endif
 
 void Connection::setRoomFactory(room_factory_t f)
@@ -1518,11 +1612,13 @@ void Connection::saveState() const
     {
         QJsonObject roomsJson;
         QJsonObject inviteRoomsJson;
-        for (const auto* r: qAsConst(d->roomMap)) {
+        for (const auto* r: std::as_const(d->roomMap)) {
             if (r->joinState() == JoinState::Leave)
                 continue;
             (r->joinState() == JoinState::Invite ? inviteRoomsJson : roomsJson)
-                .insert(r->id(), QJsonValue::Null);
+                .insert(r->id(),
+                        QJsonObject{ { "$ref"_ls,
+                                       SyncData::fileNameForRoom(r->id()) } });
         }
 
         QJsonObject roomObj;
@@ -1694,6 +1790,27 @@ void Connection::enableEncryption(bool enable)
 #endif
 }
 
+bool Connection::directChatEncryptionEnabled() const
+{
+    return d->encryptDirectChats;
+}
+
+void Connection::enableDirectChatEncryption(bool enable)
+{
+    if (enable == d->encryptDirectChats) {
+        return;
+    }
+
+#ifdef Quotient_E2EE_ENABLED
+    d->encryptDirectChats = enable;
+    emit directChatsEncryptionChanged(enable);
+#else
+    Q_UNUSED(enable)
+    qWarning(E2EE) << "The library is compiled without E2EE support, "
+                      "enabling encryption for direct chats has no effect";
+#endif
+}
+
 inline bool roomVersionLess(const Connection::SupportedRoomVersion& v1,
                             const Connection::SupportedRoomVersion& v2)
 {
@@ -1729,10 +1846,48 @@ bool Connection::isQueryingKeys() const
            && d->encryptionData->currentQueryKeysJob != nullptr;
 }
 
+void Connection::encryptionUpdate(const Room* room, const QList<QString>& invitedIds)
+{
+    if (d->encryptionData) {
+        d->encryptionData->encryptionUpdate(room->joinedMemberIds() + invitedIds);
+    }
+}
+
 void Connection::encryptionUpdate(const Room* room, const QList<User*>& invited)
 {
-    if (d->encryptionData)
-        d->encryptionData->encryptionUpdate(room->users() + invited);
+    if (d->encryptionData) {
+        QList<QString> invitedIds;
+        for (const auto& u : invited) {
+            invitedIds.append(u->id());
+        }
+        d->encryptionData->encryptionUpdate(room->joinedMemberIds() + invitedIds);
+    }
+}
+
+void Connection::requestKeyFromDevices(event_type_t name,
+                                       const std::function<void(const QByteArray&)>& then)
+{
+    UsersToDevicesToContent content;
+    const auto& requestId = generateTxnId();
+    const QJsonObject eventContent{ { "action"_ls, "request"_ls },
+                                    { "name"_ls, name },
+                                    { "request_id"_ls, requestId },
+                                    { "requesting_device_id"_ls, deviceId() } };
+    for (const auto& deviceId : devicesForUser(userId())) {
+        content[userId()][deviceId] = eventContent;
+    }
+    sendToDevices("m.secret.request"_ls, content);
+    connectUntil(this, &Connection::secretReceived, this,
+                 [this, requestId, then, name](const QString& receivedRequestId,
+                                               const QString& secret) {
+                     if (requestId != receivedRequestId) {
+                         return false;
+                     }
+                     const auto& key = QByteArray::fromBase64(secret.toLatin1());
+                     database()->storeEncrypted(name, key);
+                     then(key);
+                     return true;
+                 });
 }
 
 QJsonObject Connection::decryptNotification(const QJsonObject& notification)
@@ -1850,6 +2005,9 @@ bool Connection::isVerifiedSession(const QByteArray& megolmSessionId) const
         return false;
     }
     auto olmSessionId = query.value("olmSessionId"_ls).toString();
+    if (olmSessionId == "BACKUP_VERIFIED"_ls) {
+        return true;
+    }
     query.prepare("SELECT senderKey FROM olm_sessions WHERE sessionId=:sessionId;"_ls);
     query.bindValue(":sessionId"_ls, olmSessionId.toLatin1());
     database()->execute(query);
@@ -1891,3 +2049,13 @@ Connection* Connection::makeMockConnection(const QString& mxId,
     c->d->completeSetup(mxId, true);
     return c;
 }
+
+QStringList Connection::accountDataEventTypes() const
+{
+    QStringList events;
+    events.reserve(d->accountData.size());
+    for (const auto& [key, value] : std::as_const(d->accountData)) {
+        events += key;
+    }
+    return events;
+}
