@@ -12,9 +12,9 @@
 #include "events/roomkeyevent.h"
 
 #if QT_VERSION_MAJOR >= 6
-#    include <qt6keychain/keychain.h>
+    #include <qt6keychain/keychain.h>
 #else
-#    include <qt5keychain/keychain.h>
+    #include <qt5keychain/keychain.h>
 #endif
 
 #include <QtCore/QCoreApplication>
@@ -27,7 +27,7 @@ Expected<PicklingKey, QKeychain::Error> setupPicklingKey(const QString& id,
 {
     if (mock) {
         qInfo(E2EE) << "Using a mock pickling key";
-        return PicklingKey::mock();
+        return PicklingKey::generate();
     }
 
     // TODO: Rewrite the whole thing in an async way to get rid of nested event
@@ -83,6 +83,11 @@ ConnectionEncryptionData::setup(Connection* connection, bool mock)
     if (auto&& maybePicklingKey = setupPicklingKey(connection->userId(), mock)) {
         auto&& encryptionData = std::make_unique<ConnectionEncryptionData>(
             connection, std::move(*maybePicklingKey));
+        if (mock) {
+            encryptionData->database.clear();
+            encryptionData->olmAccount.setupNewAccount();
+            return std::move(encryptionData);
+        }
         if (const auto outcome = encryptionData->database.setupOlmAccount(
                 encryptionData->olmAccount)) {
             // account already existing or there's an error unpickling it
@@ -370,7 +375,12 @@ void ConnectionEncryptionData::handleEncryptedToDeviceEvent(
                     << "is not found at the connection" << q->objectName();
             }
         },
-        [](const Event& evt) {
+        [this](const Event& evt) {
+            //TODO create an event subclass for this
+            if (evt.matrixType() == "m.secret.send"_ls) {
+                emit q->secretReceived(evt.contentPart<QString>("request_id"_ls), evt.contentPart<QString>("secret"_ls));
+                return;
+            }
             qCWarning(E2EE) << "Skipping encrypted to_device event, type"
                             << evt.matrixType();
         });
@@ -434,12 +444,12 @@ void ConnectionEncryptionData::handleQueryKeys(const QueryKeysJob* job)
                   });
 }
 
-void ConnectionEncryptionData::encryptionUpdate(const QList<User*>& forUsers)
+void ConnectionEncryptionData::encryptionUpdate(const QList<QString>& forUsers)
 {
-    for (const auto& user : forUsers)
-        if (!trackedUsers.contains(user->id())) {
-            trackedUsers += user->id();
-            outdatedUsers += user->id();
+    for (const auto& userId : forUsers)
+        if (!trackedUsers.contains(userId)) {
+            trackedUsers += userId;
+            outdatedUsers += userId;
             encryptionUpdateRequired = true;
         }
 }
