@@ -1,6 +1,4 @@
-/******************************************************************************
- * THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
- */
+// THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
 
 #include "admin.h"
 
@@ -9,8 +7,7 @@ using namespace Quotient;
 QUrl GetWhoIsJob::makeRequestUrl(QUrl baseUrl, const QString& userId)
 {
     return BaseJob::makeRequestUrl(std::move(baseUrl),
-                                   makePath("/_matrix/client/v3",
-                                            "/admin/whois/", userId));
+                                   makePath("/_matrix/client/v3", "/admin/whois/", userId));
 }
 
 GetWhoIsJob::GetWhoIsJob(const QString& userId)
