@@ -1,24 +1,23 @@
-/******************************************************************************
- * THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
- */
+// THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
 
 #pragma once
 
-#include <Quotient/converters.h>
 #include <Quotient/csapi/definitions/push_rule.h>
 
+#include <Quotient/converters.h>
+
 namespace Quotient {
 
 struct PushRuleset {
-    QVector<PushRule> content;
+    QVector<PushRule> content{};
 
-    QVector<PushRule> override;
+    QVector<PushRule> override{};
 
-    QVector<PushRule> room;
+    QVector<PushRule> room{};
 
-    QVector<PushRule> sender;
+    QVector<PushRule> sender{};
 
-    QVector<PushRule> underride;
+    QVector<PushRule> underride{};
 };
 
 template <>
@@ -33,11 +32,11 @@ struct JsonObjectConverter<PushRuleset> {
     }
     static void fillFrom(const QJsonObject& jo, PushRuleset& pod)
     {
-        fromJson(jo.value("content"_ls), pod.content);
-        fromJson(jo.value("override"_ls), pod.override);
-        fromJson(jo.value("room"_ls), pod.room);
-        fromJson(jo.value("sender"_ls), pod.sender);
-        fromJson(jo.value("underride"_ls), pod.underride);
+        fillFromJson(jo.value("content"_ls), pod.content);
+        fillFromJson(jo.value("override"_ls), pod.override);
+        fillFromJson(jo.value("room"_ls), pod.room);
+        fillFromJson(jo.value("sender"_ls), pod.sender);
+        fillFromJson(jo.value("underride"_ls), pod.underride);
     }
 };
 
