@@ -1,21 +1,17 @@
-/******************************************************************************
- * THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
- */
+// THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
 
 #pragma once
 
 #include <Quotient/converters.h>
 
 namespace Quotient {
-/// Identification information for a user
+//! Identification information for a user
 struct UserIdentifier {
-    /// The type of identification.  See [Identifier
-    /// types](/client-server-api/#identifier-types) for supported values and
-    /// additional property descriptions.
+    //! The type of identification.  See [Identifier types](/client-server-api/#identifier-types)
+    //! for supported values and additional property descriptions.
     QString type;
 
-    /// Identification information for a user
-    QVariantHash additionalProperties;
+    QVariantHash additionalProperties{};
 };
 
 template <>
@@ -27,7 +23,7 @@ struct JsonObjectConverter<UserIdentifier> {
     }
     static void fillFrom(QJsonObject jo, UserIdentifier& pod)
     {
-        fromJson(jo.take("type"_ls), pod.type);
+        fillFromJson(jo.take("type"_ls), pod.type);
         fromJson(jo, pod.additionalProperties);
     }
 };
