@@ -1,13 +1,10 @@
-/******************************************************************************
- * THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
- */
+// THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
 
 #include "inviting.h"
 
 using namespace Quotient;
 
-InviteUserJob::InviteUserJob(const QString& roomId, const QString& userId,
-                             const QString& reason)
+InviteUserJob::InviteUserJob(const QString& roomId, const QString& userId, const QString& reason)
     : BaseJob(HttpVerb::Post, QStringLiteral("InviteUserJob"),
               makePath("/_matrix/client/v3", "/rooms/", roomId, "/invite"))
 {
