@@ -1,6 +1,4 @@
-/******************************************************************************
- * THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
- */
+// THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
 
 #include "receipts.h"
 
@@ -9,8 +7,8 @@ using namespace Quotient;
 PostReceiptJob::PostReceiptJob(const QString& roomId, const QString& receiptType,
                                const QString& eventId, const QString& threadId)
     : BaseJob(HttpVerb::Post, QStringLiteral("PostReceiptJob"),
-              makePath("/_matrix/client/v3", "/rooms/", roomId, "/receipt/",
-                       receiptType, "/", eventId))
+              makePath("/_matrix/client/v3", "/rooms/", roomId, "/receipt/", receiptType, "/",
+                       eventId))
 {
     QJsonObject _dataJson;
     addParam<IfNotEmpty>(_dataJson, QStringLiteral("thread_id"), threadId);
