@@ -1,6 +1,4 @@
-/******************************************************************************
- * THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
- */
+// THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
 
 #include "report_content.h"
 
@@ -9,8 +7,7 @@ using namespace Quotient;
 ReportContentJob::ReportContentJob(const QString& roomId, const QString& eventId,
                                    Omittable<int> score, const QString& reason)
     : BaseJob(HttpVerb::Post, QStringLiteral("ReportContentJob"),
-              makePath("/_matrix/client/v3", "/rooms/", roomId, "/report/",
-                       eventId))
+              makePath("/_matrix/client/v3", "/rooms/", roomId, "/report/", eventId))
 {
     QJsonObject _dataJson;
     addParam<IfNotEmpty>(_dataJson, QStringLiteral("score"), score);
