@@ -1,13 +1,10 @@
-/******************************************************************************
- * THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
- */
+// THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
 
 #include "users.h"
 
 using namespace Quotient;
 
-SearchUserDirectoryJob::SearchUserDirectoryJob(const QString& searchTerm,
-                                               Omittable<int> limit)
+SearchUserDirectoryJob::SearchUserDirectoryJob(const QString& searchTerm, Omittable<int> limit)
     : BaseJob(HttpVerb::Post, QStringLiteral("SearchUserDirectoryJob"),
               makePath("/_matrix/client/v3", "/user_directory/search"))
 {
