@@ -1,6 +1,4 @@
-/******************************************************************************
- * THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
- */
+// THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
 
 #include "versions.h"
 
@@ -8,8 +6,7 @@ using namespace Quotient;
 
 QUrl GetVersionsJob::makeRequestUrl(QUrl baseUrl)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
-                                   makePath("/_matrix/client", "/versions"));
+    return BaseJob::makeRequestUrl(std::move(baseUrl), makePath("/_matrix/client", "/versions"));
 }
 
 GetVersionsJob::GetVersionsJob()
