@@ -1,6 +1,4 @@
-/******************************************************************************
- * THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
- */
+// THIS FILE IS GENERATED - ANY EDITS WILL BE OVERWRITTEN
 
 #include "voip.h"
 
@@ -8,8 +6,8 @@ using namespace Quotient;
 
 QUrl GetTurnServerJob::makeRequestUrl(QUrl baseUrl)
 {
-    return BaseJob::makeRequestUrl(
-        std::move(baseUrl), makePath("/_matrix/client/v3", "/voip/turnServer"));
+    return BaseJob::makeRequestUrl(std::move(baseUrl),
+                                   makePath("/_matrix/client/v3", "/voip/turnServer"));
 }
 
 GetTurnServerJob::GetTurnServerJob()
