@@ -5,8 +5,9 @@
 
 #include "connection.h"
 #include "database.h"
+#include "logging_categories_p.h"
+
 #include "e2ee/qolmaccount.h"
-#include "olm/sas.h"
 
 #include "events/event.h"
 
@@ -14,6 +15,8 @@
 #include <QtCore/QTimer>
 #include <QtCore/QUuid>
 
+#include <olm/sas.h>
+
 #include <chrono>
 
 using namespace Quotient;
@@ -105,6 +108,16 @@ void KeyVerificationSession::handleEvent(const KeyVerificationEvent& baseEvent)
             [this](const KeyVerificationAcceptEvent& event) {
                 if (state() != WAITINGFORACCEPT)
                     return false;
+                const auto& theirMac = event.messageAuthenticationCode();
+                for (const auto& mac : SupportedMacs) {
+                    if (mac == theirMac) {
+                        m_commonMacCodes.push_back(theirMac);
+                    }
+                }
+                if (m_commonMacCodes.isEmpty()) {
+                    cancelVerification(UNKNOWN_METHOD);
+                    return false;
+                }
                 m_commitment = event.commitment();
                 sendKey();
                 setState(WAITINGFORKEY);
@@ -442,6 +455,7 @@ KeyVerificationSession::State KeyVerificationSession::state() const
 
 void KeyVerificationSession::setState(KeyVerificationSession::State state)
 {
+    qCDebug(E2EE) << "KeyVerificationSession state" << m_state << "->" << state;
     m_state = state;
     emit stateChanged();
 }
