@@ -45,8 +45,8 @@ void TestOlmAccount::identityKeysValid()
     QCOMPARE(ed25519.size(), 43);
 
     // encoded as valid base64?
-    QVERIFY(QByteArray::fromBase64(curve25519).size() > 0);
-    QVERIFY(QByteArray::fromBase64(ed25519).size() > 0);
+    QVERIFY(QByteArray::fromBase64(curve25519.toLatin1()).size() > 0);
+    QVERIFY(QByteArray::fromBase64(ed25519.toLatin1()).size() > 0);
 }
 
 void TestOlmAccount::signatureValid()
@@ -60,7 +60,7 @@ void TestOlmAccount::signatureValid()
     QOlmUtility utility;
     const auto identityKeys = olmAccount.identityKeys();
     const auto ed25519Key = identityKeys.ed25519;
-    QVERIFY(utility.ed25519Verify(ed25519Key, message, signature));
+    QVERIFY(utility.ed25519Verify(ed25519Key.toLatin1(), message, signature));
 }
 
 void TestOlmAccount::oneTimeKeysValid()
@@ -182,7 +182,7 @@ void TestOlmAccount::uploadIdentityKey()
 
     UnsignedOneTimeKeys unused;
     auto request = olmAccount->createUploadKeyRequest(unused);
-    connect(request, &BaseJob::result, this, [request, conn] {
+    connect(request, &BaseJob::result, this, [request] {
         if (!request->status().good())
             QFAIL("upload failed");
         const auto& oneTimeKeyCounts = request->oneTimeKeyCounts();
@@ -204,15 +204,14 @@ void TestOlmAccount::uploadOneTimeKeys()
     auto nKeys = olmAccount->generateOneTimeKeys(5);
     QCOMPARE(nKeys, 5);
 
-    auto oneTimeKeys = olmAccount->oneTimeKeys();
+    const auto oneTimeKeys = olmAccount->oneTimeKeys();
 
     OneTimeKeys oneTimeKeysHash;
-    const auto curve = oneTimeKeys.curve25519();
-    for (const auto &[keyId, key] : asKeyValueRange(curve)) {
+    for (const auto& [keyId, key] : asKeyValueRange(oneTimeKeys.curve25519())) {
         oneTimeKeysHash["curve25519:"_ls + keyId] = key;
     }
     auto request = new UploadKeysJob(none, oneTimeKeysHash);
-    connect(request, &BaseJob::result, this, [request, conn] {
+    connect(request, &BaseJob::result, this, [request] {
         if (!request->status().good())
             QFAIL("upload failed");
         QCOMPARE(request->oneTimeKeyCounts().value(Curve25519Key), 5);
@@ -230,13 +229,9 @@ void TestOlmAccount::uploadSignedOneTimeKeys()
     QCOMPARE(nKeys, 5);
 
     auto oneTimeKeys = olmAccount->oneTimeKeys();
-    OneTimeKeys oneTimeKeysHash;
-    const auto signedKey = olmAccount->signOneTimeKeys(oneTimeKeys);
-    for (const auto &[keyId, key] : asKeyValueRange(signedKey)) {
-        oneTimeKeysHash[keyId] = key;
-    }
+    auto oneTimeKeysHash = olmAccount->signOneTimeKeys(oneTimeKeys);
     auto request = new UploadKeysJob(none, oneTimeKeysHash);
-    connect(request, &BaseJob::result, this, [request, nKeys, conn] {
+    connect(request, &BaseJob::result, this, [request, nKeys] {
         if (!request->status().good())
             QFAIL("upload failed");
         QCOMPARE(request->oneTimeKeyCounts().value(SignedCurve25519Key), nKeys);
@@ -254,7 +249,7 @@ void TestOlmAccount::uploadKeys()
     olmAccount->generateOneTimeKeys(1);
     auto otks = olmAccount->oneTimeKeys();
     auto request = olmAccount->createUploadKeyRequest(otks);
-    connect(request, &BaseJob::result, this, [request, conn] {
+    connect(request, &BaseJob::result, this, [request] {
         if (!request->status().good())
             QFAIL("upload failed");
         QCOMPARE(request->oneTimeKeyCounts().value(SignedCurve25519Key), 1);
@@ -456,7 +451,6 @@ void TestOlmAccount::enableEncryption()
     QVERIFY(createRoomSpy.wait(10000));
     alice->sync();
     connect(alice.get(), &Connection::syncDone, this, [alice](){
-        qDebug() << "foo";
         alice->sync();
     });
     while(alice->roomsCount(JoinState::Join) == 0) {
